@@ -635,7 +635,7 @@ void KGameWindow::initCombatMovement()
       sndRoulePath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/roll.wav");
       if (sndRoulePath.isNull())
       {
-        KMessageBox::error(nullptr, i18n("Sound roule not found - Verify your installation<br>Program cannot continue"), i18n("Error!"));
+        KMessageBox::error(nullptr, i18n("Sound roule not found - Verify your installation<br>Program cannot continue"));
         exit(2);
       }
       if (KsirkSettings::soundEnabled())
@@ -750,7 +750,7 @@ void KGameWindow::initCombatMovement()
       sndRoulePath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/roll.wav");
       if (sndRoulePath.isNull())
       {
-        KMessageBox::error(nullptr, i18n("Sound roule not found - Verify your installation<br>Program cannot continue"), i18n("Error!"));
+        KMessageBox::error(nullptr, i18n("Sound roule not found - Verify your installation<br>Program cannot continue"));
         exit(2);
       }
       if (KsirkSettings::soundEnabled())
@@ -795,7 +795,7 @@ void KGameWindow::animCombat()
     if (sndCanonPath.isNull())
     {
       KMessageBox::error(nullptr,
-          i18n("Sound cannon not found - Verify your installation<br>Program cannot continue"), i18n("Error!"));
+          i18n("Sound cannon not found - Verify your installation<br>Program cannot continue"));
       exit(2);
     }
     if (KsirkSettings::soundEnabled())
@@ -870,7 +870,7 @@ void KGameWindow::animExplosion(int who)
         QString sndCrashPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/crash.wav");
         if (sndCrashPath.isNull())
         {
-          KMessageBox::information(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"), i18n("KsirK - Error!"));
+          KMessageBox::error(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"));
           exit(2);
         }
         if (KsirkSettings::soundEnabled())
@@ -890,7 +890,7 @@ void KGameWindow::animExplosion(int who)
         QString sndCrashPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/crash.wav");
         if (sndCrashPath.isNull())
         {
-          KMessageBox::information(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"), i18n("KsirK - Error!"));
+          KMessageBox::error(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"));
           exit(2);
         }
         if (KsirkSettings::soundEnabled())
@@ -930,7 +930,7 @@ void KGameWindow::animExplosion(int who)
   /*QString sndCrashPath = m_dirs-> findResource("appdata", m_automaton->skin() + "/Sounds/crash.wav");
   if (sndCrashPath.isNull())
   {
-    KMessageBox::information(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"), i18n("KsirK - Error!"));
+    KMessageBox::error(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"));
     exit(2);
   }
   if (KsirkSettings::soundEnabled())
@@ -991,7 +991,7 @@ void KGameWindow::animExplosionForArena()
           QString sndCrashPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/crash.wav");
           if (sndCrashPath.isNull())
           {
-            KMessageBox::information(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"), i18n("KsirK - Error!"));
+            KMessageBox::error(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"));
             exit(2);
           }
           if (KsirkSettings::soundEnabled())
@@ -1028,7 +1028,7 @@ void KGameWindow::animExplosionForArena()
           QString sndCrashPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/crash.wav");
           if (sndCrashPath.isNull())
           {
-            KMessageBox::information(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"), i18n("KsirK - Error!"));
+            KMessageBox::error(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"));
             exit(2);
           }
           if (KsirkSettings::soundEnabled())
@@ -1063,7 +1063,7 @@ void KGameWindow::animExplosionForArena()
           QString sndCrashPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/crash.wav");
           if (sndCrashPath.isNull())
           {
-            KMessageBox::information(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"), i18n("KsirK - Error!"));
+            KMessageBox::error(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"));
             exit(2);
           }
           if (KsirkSettings::soundEnabled())
@@ -1117,7 +1117,7 @@ void KGameWindow::animExplosionForArena()
           QString sndCrashPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/crash.wav");
           if (sndCrashPath.isNull())
           {
-            KMessageBox::information(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"), i18n("KsirK - Error!"));
+            KMessageBox::error(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"));
             exit(2);
           }
           if (KsirkSettings::soundEnabled())
@@ -1154,7 +1154,7 @@ void KGameWindow::animExplosionForArena()
           QString sndCrashPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/crash.wav");
           if (sndCrashPath.isNull())
           {
-            KMessageBox::information(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"), i18n("KsirK - Error!"));
+            KMessageBox::error(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"));
             exit(2);
           }
           if (KsirkSettings::soundEnabled())
@@ -1188,7 +1188,7 @@ void KGameWindow::animExplosionForArena()
           QString sndCrashPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/crash.wav");
           if (sndCrashPath.isNull())
           {
-            KMessageBox::information(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"), i18n("KsirK - Error!"));
+            KMessageBox::error(this, i18n("Sound crash not found - Verify your installation\nProgram cannot continue"));
             exit(2);
           }
           if (KsirkSettings::soundEnabled())
@@ -1351,7 +1351,7 @@ void KGameWindow::initCombatBringBackForArena(Country *attackingCountry, Country
     QString sndRoulePath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/roll.wav");
     if (sndRoulePath.isNull())
     {
-        KMessageBox::error(nullptr, i18n("Sound roule not found - Verify your installation<br>Program cannot continue"), i18n("Error!"));
+        KMessageBox::error(nullptr, i18n("Sound roule not found - Verify your installation<br>Program cannot continue"));
         exit(2);
     }
     if (KsirkSettings::soundEnabled())
@@ -1428,7 +1428,7 @@ void KGameWindow::initCombatBringBackForArena(Country *attackingCountry, Country
       QString sndRoulePath = QStandardPaths::locate(QStandardPaths::AppDataLocation, m_automaton->skin() + "/Sounds/roll.wav");
       if (sndRoulePath.isNull())
       {
-          KMessageBox::error(nullptr, i18n("Sound roule not found - Verify your installation<br>Program cannot continue"), i18n("Error!"));
+          KMessageBox::error(nullptr, i18n("Sound roule not found - Verify your installation<br>Program cannot continue"));
           exit(2);
       }
       if (KsirkSettings::soundEnabled())
